@@ -741,3 +741,12 @@ class VariableClRsyncVer(ReadonlyVariable):
         if data:
             return data[0]['PVR']
         return ""
+
+
+class VariableClSyncMovedSet(Variable):
+    """
+    Использовать или нет перенос файлов из домашней директории в Home/Moved при
+    синхронизации
+    """
+    type = "bool"
+    value = "on"
